@@ -118,14 +118,14 @@ class StepsExecutor(object):
     CMD_CLEAR_APP_DIR = 'rm -rf /data/app/*; cd /data; tar -xf app.tar'
     
     CMD_INIT_CSNODE_INFO = 'sed -i \'/cluster_service_nodes/{{n;d;}}\' /root/{prepack_name}/install_sysInfo.json;' + \
-            'sed -i \'/cluster_service_nodes/a {{"ip":"{installer_ip}", "user":"cms", "password":"cms1234", "rootPasswd":"root1234"}}\' /root/{prepack_name}/install_sysInfo.json;' + \
+            'sed -i \'/cluster_service_nodes/a {{"ip":"{installer_ip}"}}\' /root/{prepack_name}/install_sysInfo.json;' + \
             'sed -i \'/cluster_service_nodes/{{n;d;}}\' /root/{prepack_name}/upgrade_sysInfo.json;' + \
-            'sed -i \'/cluster_service_nodes/a {{"ip":"{installer_ip}", "user":"cms", "password":"cms1234", "rootPasswd":"root1234"}}\' /root/{prepack_name}/upgrade_sysInfo.json'
+            'sed -i \'/cluster_service_nodes/a {{"ip":"{installer_ip}"}}\' /root/{prepack_name}/upgrade_sysInfo.json'
             
     CMD_INIT_APP_INFO = 'sed -i \'/cluster_app_nodes/{{n;d;}}\' /root/{prepack_name}/install_sysInfo.json;' + \
-                        'sed -i \'/cluster_app_nodes/a {{"ip":"{app_ip}", "user":"cms", "password":"cms1234", "rootPasswd":"root1234"}}],\' /root/{prepack_name}/install_sysInfo.json;' + \
+                        'sed -i \'/cluster_app_nodes/a {{"ip":"{app_ip}"}}],\' /root/{prepack_name}/install_sysInfo.json;' + \
                         'sed -i \'/cluster_app_nodes/{{n;d;}}\' /root/{prepack_name}/upgrade_sysInfo.json;' + \
-                        'sed -i \'/cluster_app_nodes/a {{"ip":"{app_ip}", "user":"cms", "password":"cms1234", "rootPasswd":"root1234"}}],\' /root/{prepack_name}/upgrade_sysInfo.json' 
+                        'sed -i \'/cluster_app_nodes/a {{"ip":"{app_ip}"}}],\' /root/{prepack_name}/upgrade_sysInfo.json' 
     
     CMD_BEFORE_REFRESH_01 = '[ -e /tmp/contentClassSrc.xml ] && cp -vf /tmp/contentClassSrc.xml /root/Jenkins_Automation/contentClassSrc.xml.{tailing_flag}'
     CMD_BEFORE_REFRESH_02 = '[ -e /tmp/cms_file_monitor.json ] && cp -vf /tmp/cms_file_monitor.json /root/Jenkins_Automation/cms_file_monitor.json.{tailing_flag}'
